@@ -18,6 +18,8 @@
 #' @export
 get_trees_filenames <- function(input_filename) {
 
-  alignment_ids <- get_alignment_ids(input_filename) # nolint internal function
+  alignment_ids <- get_alignment_ids_from_xml_filename( # nolint beastier function
+    xml_filename = input_filename
+  )
   paste0(alignment_ids, ".trees")
 }
