@@ -8,11 +8,14 @@
 #'
 #'   expect_false(is_jar_path("beast"))
 #'   expect_true(is_jar_path("beast.jar"))
+#'   expect_true(is_jar_path("launcher.jar"))
 #'   expect_false(is_jar_path(get_default_beast2_bin_path()))
 #'   expect_true(is_jar_path(get_default_beast2_jar_path()))
-#' @noRd
+#' @export
 is_jar_path <- function(path) {
+  # Windows    : BEAST/lib/beast.jar                                            # nolint
+  # Non-Windows: beast/lib/launcher.jar                                         # nolint
   !beautier::is_one_na(stringr::str_match(
-    path, "(.*/)?beast\\.jar$")[1][1]
+    path, "(.*/)?(launcher|beast)\\.jar$")[1][1]
   )
 }
